﻿/*
 * JavaScript file
 */
var cities = [{
    id: 1,
    text: "London",
    value: "London"
}, {
    id: 2,
    text: "Paris",
    value: "Paris"
}, {
    id: 3,
    text: "Manchester",
    value: "Manchester"
}, {
    id: 4,
    text: "New York",
    value: "New York"
}];

var city = "";
var useMetricSystem = true;
var hasText = false;
var result;
var tryingV2 = false;
$(document).ready(function(){
    function loadSettings(){
        if (window.widget) {
            checkNewVersion();
            
            if (typeof widget.preferenceForKey("Cities") != 'undefined') {
                var _cities = widget.preferenceForKey("Cities");
                cities = JSON.parse(_cities);
            }
            
            if (typeof widget.preferenceForKey("UseMetricSystem") != 'undefined') {
                var _useMetricSystem = widget.preferenceForKey("UseMetricSystem");
                useMetricSystem = JSON.parse(_useMetricSystem);
            }
			
			setMetricSystem();
            updateList();
        }
    }
    
    function checkNewVersion(){
        var loadTimeout = setTimeout(errorFunc, 20100);
        $.ajax({
            url: "http://serhatozgel.com/cesium/theweather/lastversionen",
            type: 'GET',
            dataType: 'jsonp',
            success: function(version){
                clearTimeout(loadTimeout);
                if (version != '1.0') {
                    if (confirm("An update found. Press OK to continiue...")) {
                        widget.openURL('http://store.ovi.mobi/content/163131');
                    }
                }
            },
            timeout: 20000
        });
    }
    
    function errorFunc(){
        alert("Cannot connect to the server. Please try again later.");
    }
    
    function addCity(cityText){
        var maxId = getMaxId();
        maxId++;
        cities.push({
            id: maxId,
            text: cityText,
            value: cityText
        });
        saveCity();
        updateList();
    }
    
    function getMaxId(){
        var maxId = 0;
        $(cities).each(function(index){
            if (maxId <= $(this)[0].id) {
                maxId = $(this)[0].id;
            }
        });
        
        return maxId;
    }
    
    function saveCity(){
        if (window.widget) {
            widget.setPreferenceForKey(JSON.stringify(cities), "Cities");
        }
    }
    
    function updateList(){
        $("#cities").empty();
        createCityItem(0, 'Current', '_current');
        $(cities).each(function(index){
            createCityItem($(this)[0].id, $(this)[0].text, $(this)[0].value);
        });
        
        if ($(".marked-item").length == 0) {
            $("#deleteSelected").css({
                "display": "none"
            })
        }
    }
	
	function setMetricSystem(){
		if (useMetricSystem) {
            $("#use_metric_system").removeClass("uncheck");
            $("#use_metric_system").addClass("check");;
        }
        else {
			$("#use_metric_system").removeClass("check");
            $("#use_metric_system").addClass("uncheck")
        }
	}
    
    function createCityItem(id, text, value){
        var cityItem = document.createElement("div");
        $(cityItem).addClass("city-item");
        var textItem = document.createElement("div");
        $(textItem).addClass("text-item");
        $(textItem).bind('click', getSelectedCityWeather);
        $(textItem).append(text);
        $(cityItem).append(textItem);
        $(cityItem).bind('mousedown', applyMouseDown);
        $(cityItem).bind('mouseup', applyMouseUp);
        $(cityItem).bind('mouseenter', applyMouseDown);
        $(cityItem).bind('mouseleave', applyMouseUp);
        $(cityItem).bind('mouseover', applyMouseDown);
        $(cityItem).bind('mouseout', applyMouseUp);
        
        if (value != "_current") {
            var removeItem = document.createElement("div");
            $(removeItem).addClass("remove-item");
            $(removeItem).html("x");
            $(removeItem).bind('click', markSelectedCityAsDeleted);
            $(cityItem).append(removeItem);
        }
        else {
            $(textItem).css({
                "width": "100%"
            });
        }
        
        var hiddenField = document.createElement("input");
        $(hiddenField).attr("type", "hidden");
        $(hiddenField).addClass("city");
        $(hiddenField).attr("id", "city_" + id);
        $(hiddenField).val(value);
        
        $(cityItem).append(hiddenField);
        $("#cities").append(cityItem);
    }
    
    window.onresize = function(){
        if (window.menu) {
            window.menu.hideSoftkeys();
        }
        
        setPortrait();
    }
    
    function setPortrait(){
		
        if (widget.isrotationsupported) {
            widget.setDisplayPortrait();
        }
    }
    
    window.onload = function(){
        setPortrait();
    }
    
	if (window.menu) {
    	window.menu.hideSoftkeys();
    }
		
    if (window.widget) {
        loadSettings();
    }
    
    $("#retrieveForecast").click(function(){
        city = "";
        var place = $("#search_view #searchPlace").val();
        $("#search_view #message").html("Retrieving weather report...");
        var loadTimeout = setTimeout(errorFunc, 20100);
        $.ajax({
            url: "http://pipes.yahoo.com/pipes/pipe.run?_id=15ea6da13da705add73e7bf7420f5f65&_render=json&city=" + place + "&_callback=?",
            type: 'GET',
            dataType: 'json',
            success: function(data){
                clearTimeout(loadTimeout);
                showWeather(data);
            },
            timeout: 20000,
            error: errorFunc
        });
    });
    
    function showWeather(data){
        result = data.value.items[0];
        if (result == undefined || result.city == undefined) {
            if (tryingV2) {
                $("#search_view #nothing_found").css({
                    "display": "block"
                });
                $("#search_view #forecast").css({
                    "display": "none"
                });
                $("#search_view #loading").css({
                    "display": "none"
                });
                
                $("#search_view #message").html("");
            }
            else {
                tryingV2 = true;
                var place = $("#search_view #searchPlace").val();
                var loadTimeout = setTimeout(errorFunc, 20100);
                $.ajax({
                    url: "http://pipes.yahoo.com/pipes/pipe.run?_id=ee6d420349d95cef67c233d9df7322f6&_render=json&city=" + place + "&_callback=?",
                    type: 'GET',
                    dataType: 'json',
                    success: function(data){
                        clearTimeout(loadTimeout);
                        showWeather(data);
                    },
                    timeout: 20000,
                    error: errorFunc
                });
                return;
            }
        }
        else {
            $("#search_view #nothing_found").css({
                "display": "none"
            });
            $("#search_view #forecast").css({
                "display": "block"
            });
            
            if (showAddLocation) {
                var isExistingCity = false;
                $(cities).each(function(index){
                    if ($(this)[0].text.toLowerCase() == currentLocation.toLowerCase()) {
                        isExistingCity = true;
                    }
                });
                
                if (!isExistingCity) {
                    $("#search_view .current-location").css({
                        "display": "block"
                    });
                }
            }
            
            city = result.city;
            if (city.indexOf(' Province') > 0) {
                var splitted = city.split(' Province');
                city = splitted[0]
            }
            
            $("#search_view #message").html("");
            var condition = result.current.condition.data;
            $("#search_view #forecast #condition #city").html(city);
            var imageLink = getGoogleImageLink(result.current.condition.data);
            var minDegree;
            var maxDegree;
			var currentDegree;
            if (useMetricSystem) {
                minDegree = convertToCelcius(result.weather.forecast_conditions[0].low.data);
                maxDegree = convertToCelcius(result.weather.forecast_conditions[0].high.data);
				currentDegree = result.current.temp_c.data;
            }
            else {
                minDegree = result.weather.forecast_conditions[0].low.data;
                maxDegree = result.weather.forecast_conditions[0].high.data;
				currentDegree = result.current.temp_f.data;
            }
			
            $("#search_view #forecast #condition #image").html(imageLink);
            $("#search_view #forecast #condition #status").html(condition);
            $("#search_view #forecast #condition #temp").html(currentDegree + "º");
            $("#search_view #forecast #today #high").html(maxDegree + "º");
            $("#search_view #forecast #today #low").html(minDegree + "º");
            
            setDailyConditions(result.weather.forecast_conditions[1], 1);
            setDailyConditions(result.weather.forecast_conditions[2], 2);
            setDailyConditions(result.weather.forecast_conditions[3], 3);
            
            $("#search_view #loading").css({
                "display": "none"
            });
            $("#search_view #forecast").css({
                "display": "block"
            });
        }
        
        tryingV2 = false;
    }
    
    $(".marked-item").click(unmarkSelectedCityAsDeleted);
    
    $("#use_metric_system").click(function(){
        useMetricSystem = !$(this).hasClass("check");
		setMetricSystem();
		saveSettings();
    });
    
    function saveSettings(){
        if (window.widget) {
            widget.setPreferenceForKey(JSON.stringify(useMetricSystem), "UseMetricSystem");
        }
    }
    
    $("#back").click(function(){
        var selectedCity = $(this).find(".city").val();
        $("#search_view #place").val('');
        $("#home_view").css({
            "display": "block"
        });
        $("#search_view").css({
            "display": "none"
        });
        $("#search_view .current-location").css({
            "display": "none"
        });
        
        showAddLocation = false;
        $("#addToList").hide();
		$("#addToList").addClass("add-to-list");
		$("#addToList").removeClass("added-to-list");
    });
    
    $("#back").mouseover(applyMouseDown);
    $("#back").mousedown(applyMouseDown);
    $("#back").mouseenter(applyMouseDown);
    
    $("#back").mouseout(applyMouseUp);
    $("#back").mouseup(applyMouseUp);
    $("#back").mouseleave(applyMouseUp);
    
    $("#addToList").click(function(){
        if (currentLocation == "") 
            return;
        
        var isExistingCity = false;
        $(cities).each(function(index){
            if ($(this)[0].text.toLowerCase() == currentLocation.toLowerCase()) {
                isExistingCity = true;
            }
        });
        
        if (!isExistingCity) {
            addCity(currentLocation);
            saveCity();
        }
        
        $("#addToList").removeClass('add-to-list');
		$("#addToList").addClass('added-to-list');
    });
    
    $(".current-location").mouseover(applyMouseDown);
    $(".current-location").mousedown(applyMouseDown);
    $(".current-location").mouseenter(applyMouseDown);
    
    $(".current-location").mouseout(applyMouseUp);
    $(".current-location").mouseup(applyMouseUp);
    $(".current-location").mouseleave(applyMouseUp);
    
    $("#addCity").click(function(){
        var place = $("#inputs #place").val();
        if (place == "" || !hasText) 
            return;
        
        $("#inputs #place").val("");
        var isExistingCity = false;
        $(cities).each(function(index){
            if ($(this)[0].text.toLowerCase() == place.toLowerCase()) {
                isExistingCity = true;
            }
        });
        
        if (!isExistingCity) {
            place = place.substr(0, 1).toUpperCase() + place.substr(1, place.length - 1).toLowerCase();
            
            addCity(place);
            saveCity();
        }
        
        hasText = false;
        clearPlaceText();
    });
    
    $("#deleteSelected").click(function(){
        var _cities = {};
        $(".marked-item").each(function(index){
            markedCityId = $(this).parent().find(".city").attr("id").split("_")[1];
            $(cities).each(function(cityIndex){
                if ($(this)[0].id == markedCityId) {
                    cities.splice(cityIndex, 1);
                }
            });
        });
        
        saveCity();
        updateList();
    });
    
    $("#deleteSelected").mouseover(applyMouseDown);
    $("#deleteSelected").mousedown(applyMouseDown);
    $("#deleteSelected").mouseenter(applyMouseDown);
    
    $("#deleteSelected").mouseout(applyMouseUp);
    $("#deleteSelected").mouseup(applyMouseUp);
    $("#deleteSelected").mouseleave(applyMouseUp);
    
    $("#exit").click(function(){
        window.close();
    });
    
    $("#exit").mouseover(applyMouseDown);
    $("#exit").mousedown(applyMouseDown);
    $("#exit").mouseenter(applyMouseDown);
    
    $("#exit").mouseout(applyMouseUp);
    $("#exit").mouseup(applyMouseUp);
    $("#exit").mouseleave(applyMouseUp);
    
    $("#home_view #place").focusin(function(){
        if (!hasText) {
            $("#home_view #place").val("");
            $("#home_view #place").css({
                "color": "#666"
            });
            
            hasText = true;
        }
    });
    
    $("#home_view #place").focusout(function(){
        var place = $("#home_view #place").val();
        if (place == "" || place == undefined) {
            hasText = false;
            $("#home_view #place").val("Type a city...");
            $("#home_view #place").css({
                "color": "#dedede"
            });
        }
    });
    
    $(".bottom-menu-item").click(function(){
        $(".main-view").hide();
        $(".popup-view").hide();
        
        var id = $(this).attr("id");
        $("#" + id + "_view").show();
		$(".current-location").hide();
		showAddLocation = false;
    });
    
    function clearPlaceText(){
        var place = $("#home_view #place").val();
        if (place == "" || place == undefined) {
            hasText = false;
            $("#home_view #place").val("Type a city...");
            $("#home_view #place").css({
                "color": "#dedede"
            });
        }
        else {
            hasText = true;
        }
    }
    function applyMouseDown(){
        $(this).addClass("mouse-down");
    }
    
    function applyMouseUp(){
        $(this).removeClass("mouse-down");
    }
    
    var showAddLocation = false;
    var currentLocation = "";
    function getSelectedCityWeather(){
        var selectedCity = $(this).parent().find(".city").val();
        
        $("#home_view").css({
            "display": "none"
        });
        $("#search_view").css({
            "display": "block"
        });
        $("#search_view #nothing_found").css({
            "display": "none"
        });
        $("#search_view #forecast").css({
            "display": "none"
        });
        $("#search_view #loading").css({
            "display": "block"
        });
        
        if (selectedCity == "_current") {
            showAddLocation = true;
            $("#search_view #message").html("Getting your location...");
            setTimeout(getLocationTextByGps, 1000);
        }
        else {
            $("#search_view #searchPlace").val(selectedCity);
            $("#search_view #retrieveForecast").click();
        }
    }
    
    function markSelectedCityAsDeleted(){
        $(this).removeClass('remove-item');
        $(this).addClass('marked-item');
        $(this).bind('click', unmarkSelectedCityAsDeleted);
        
        if ($(".marked-item").length > 0) {
            $("#deleteSelected").css({
                "display": "block"
            })
        }
    }
    
    function unmarkSelectedCityAsDeleted(){
        $(this).removeClass('marked-item');
        $(this).addClass('remove-item');
        $(this).bind('click', markSelectedCityAsDeleted);
        
        if ($(".marked-item").length == 0) {
            $("#deleteSelected").css({
                "display": "none"
            })
        }
    }
    
    function getGoogleImageLink(iconAddress, isMiniImage){
        var icon = iconAddress.toLowerCase().replace(/ /g, "_");
        icon = getImageName(icon) + ".png";
        return isMiniImage ? "<img class='mini-weather-image' src='images/weather/" + icon + "' />" : "<img src='images/weather/" + icon + "' />";
    }
    
    function convertToCelcius(fahreneid){
        return Math.round((fahreneid - 32) / 1.8);
    }
    
    function setDailyConditions(forecast, day){
        var forecastImageLink = getGoogleImageLink(forecast.condition.data, true);
        var minDegree;
        var maxDegree;
        if (useMetricSystem) {
            minDegree = convertToCelcius(forecast.low.data);
            maxDegree = convertToCelcius(forecast.high.data);
        }
        else {
            minDegree = forecast.low.data;
            maxDegree = forecast.high.data;
        }
        
        $("#search_view #forecast #condition #tomorrow #day_" + day + " #day_of_week_" + day).html(forecast.day_of_week.data);
        $("#search_view #forecast #condition #tomorrow #day_" + day + " #high_" + day).html(maxDegree + "º");
        $("#search_view #forecast #condition #tomorrow #day_" + day + " #low_" + day).html(minDegree + "º");
        $("#search_view #forecast #condition #tomorrow #day_" + day + " #image_" + day).html(forecastImageLink);
    }
    
    function getImageLink(conditionCode){
        return "<img src='images/weather/" + conditionCode.toLowerCase().replace(' ', '_') + ".png' />";
    }
    
    var so;
    
    // ErrorCallback function
    function errorCB(positionError){
        alert("ErrorCode: " + positionError.code + " ErrorMessage: " + positionError.message);
    }
    
    function getLocationTextByGps(){
        try {
        
            // This specifies update option used while retrieving location estimation. 
            var updateoptions = new Object();
            // Setting PartialUpdates to 'FALSE' ensures that user get atleast 
            // BasicLocationInformation (Longitude, Lattitude, and Altitude.)
            updateoptions.PartialUpdates = false;
            
            var criteria = new Object();
            criteria.LocationInformationClass = "GenericLocationInfo";
            criteria.Updateoptions = updateoptions;
            
            if (so == undefined) {
                so = device.getServiceObject("Service.Location", "ILocation");
            }
            var result = so.ILocation.GetLocation(criteria);
            
            // position coordinates
            var longitude = result.ReturnValue.Longitude;
            var latitude = result.ReturnValue.Latitude;
            
            //var latitude = 40.898717;
            //var longitude = 31.035974;
            
            //$("#search_view .to-menu div").html(latitude + "," + longitude);
            var loadTimeOut = setTimeout(errorFunc, 20100);
            $.ajax({
                url: "http://pipes.yahoo.com/pipes/pipe.run?_id=317ff4ee2c1675c4e7081f2920d7f18a&_render=json&latitude=" + latitude + "&longitude=" + longitude + "&_callback=?",
                type: 'GET',
                dataType: 'json',
                success: function(data){
                    clearTimeout(loadTimeOut);
                    setLocation(data);
                },
                timeout: 20000,
                error: errorFunc
            });
            //$.getJSON("http://pipes.yahoo.com/pipes/pipe.run?_id=317ff4ee2c1675c4e7081f2920d7f18a&_render=json&latitude=" + latitude + "&longitude=" + longitude + "&_callback=?", setLocation);
        } 
        catch (e) {
            $("#search_view #message").html(e.message);
        }
    }
    
    function errorFunc(){
    
    }
    
    function setLocation(data){
    
        var result = data.value.items[0];
        if (result.Error == 0) {
            var selectedCity = '';
            if (result.province == undefined) {
                if (result.county == undefined) {
                    selectedCity = result.city;
                }
                else {
                    selectedCity = result.county;
                }
            }
            else {
                selectedCity = result.province;
            }
            
            $("#search_view #message").html(selectedCity);
            
            currentLocation = selectedCity;
            $("#search_view #message").html(selectedCity);
            $("#search_view #searchPlace").val(selectedCity);
            $("#search_view #retrieveForecast").click();
        }
    }
    
    function getImageName(condition){
        switch (condition.toLowerCase()) {
            case "chance_of_rain":
                return "chance_of_rain";
                
            case "chance_of_snow":
                return "chance_of_snow";
                
            case "chance_of_storm":
                return "chance_of_storm";
                
            case "chance_of_thunderstorm":
                return "chance_of_thunderstorm";
                
            case "clear":
                return "clear";
                
            case "cloudy":
                return "cloudy";
                
            case "dust":
                return "dust";
                
            case "flurries":
                return "flurries";
                
            case "fog":
                return "fog";
                
            case "haze":
                return "haze";
                
            case "heavy_rain":
                return "heavy_rain";
                
            case "icy":
                return "icy";
                
            case "light_rain":
                return "light_rain";
                
            case "mist":
                return "mist";
                
            case "mostly_cloudy":
                return "mostly_cloudy";
                
            case "mostly_sunny":
                return "mostly_sunny";
                
            case "na":
                return "na";
                
            case "partly_cloudy":
                return "partly_cloudy";
                
            case "partly_sunny":
                return "partly_sunny";
                
            case "rain_showers":
                return "rain_showers";
                
            case "rain":
                return "rain";
                
            case "scattered_showers":
                return "scattered_showers";
                
            case "scattered_thunderstorms":
                return "scattered_thunderstorms";
                
            case "showers":
                return "showers";
                
            case "drizzle":
            case "sleet":
                return "sleet";
                
            case "smoke":
                return "smoke";
                
            case "snow":
                return "snow";
                
            case "storm":
                return "storm";
                
            case "sunny":
                return "sunny";
                
            case "thunderstorm":
            case "thunder_storm":
                return "thunderstorm";
                
            case "windy":
                return "windy";
                
            case "chance_of_showers":
                return "chance_of_showers";
            case "overcast":
                return "overcast";
            case "snow_showers":
                return "snow_showers";
            case "rain_and_snow":
                return "rain_and_snow";
            case "isolated_thunderstorms":
                return "isolated_thunderstorms";
            default:
                return "na";
        }
    }
});

